#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 gitrev
version:              1.3.1
visibility:           public
id:                   gitrev-1.3.1-IeAYO8QUG62LW4J3MUanQA
key:                  gitrev-1.3.1-IeAYO8QUG62LW4J3MUanQA
license:              BSD-3-Clause
maintainer:           acfoltzer@galois.com
author:               Adam C. Foltzer
homepage:             https://github.com/acfoltzer/gitrev
synopsis:             Compile git revision info into Haskell projects
description:
    Some handy Template Haskell splices for including the current git hash and branch in the code of your project. Useful for including in panic messages, @--version@ output, or diagnostic info for more informative bug reports.

category:             Development
abi:                  da37da324b9c2b306f7435805babf657
exposed:              True
exposed-modules:      Development.GitRev
import-dirs:          /usr/lib/ghc-8.10.5/site-local/gitrev-1.3.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/gitrev-1.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/gitrev-1.3.1
hs-libraries:         HSgitrev-1.3.1-IeAYO8QUG62LW4J3MUanQA
depends:
    base-4.14.2.0 base-compat-0.11.2-Eyusxyk2CrTGloLdon9bIK
    directory-1.3.6.0 filepath-1.4.2.1 process-1.6.9.0
    template-haskell-2.16.0.0

haddock-interfaces:   /usr/share/doc/haskell-gitrev/html/gitrev.haddock
haddock-html:         /usr/share/doc/haskell-gitrev/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

